@@ -44,15 +44,20 @@ class TestServiceDocumenter(BaseDocsTest):
             'Client',
             '======',
             '.. py:class:: MyService.Client',
-            '  A low-level client representing AWS MyService::',
+            '  A low-level client representing AWS MyService',
+            '  AWS MyService Description',
             '    client = session.create_client(\'myservice\')',
             '  These are the available methods:',
-            '  *   :py:meth:`sample_operation`',
+            '  *   :py:meth:`~MyService.Client.sample_operation`',
             '  .. py:method:: sample_operation(**kwargs)',
             '    **Examples** ',
             '    Sample Description.',
             '    ::',
             '      response = client.sample_operation(',
+            '=================',
+            'Client Exceptions',
+            '=================',
+            'Client exceptions are available',
             '==========',
             'Paginators',
             '==========',
